aboutsummaryrefslogtreecommitdiff
path: root/src/avp
diff options
context:
space:
mode:
Diffstat (limited to 'src/avp')
-rw-r--r--src/avp/command.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/avp/command.py b/src/avp/command.py
index 61612ef..7a77848 100644
--- a/src/avp/command.py
+++ b/src/avp/command.py
@@ -265,7 +265,7 @@ class Command(QtCore.QObject):
logNumber = 0
def getFilename():
"""Get a numbered filename for the final test report"""
nonlocal logNumber
name = os.path.join(os.path.expanduser("~"), "avp_log")
while True:
@@ -276,10 +276,10 @@ class Command(QtCore.QObject):
break
return possibleName
# Copy latest debug log to chosen test report location
filename = getFilename()
if logNumber == 100:
- print("Test Report could not be created.")
+ print("Log file could not be created (too many exist).")
return
try:
shutil.copy(os.path.join(core.Core.logDir, "avp_debug.log"), filename)
@@ -265,7 +265,7 @@ class Command(QtCore.QObject):
logNumber = 0
def getFilename():
- """Get a numbered filename for the final test report"""
+ """Get a numbered filename for the final log file"""
nonlocal logNumber
name = os.path.join(os.path.expanduser("~"), "avp_log")
@@ -276,10 +276,10 @@ class Command(QtCore.QObject):
break
return possibleName
- # Copy latest debug log to chosen test report location
+ # Copy latest debug log to chosen log file location
filename = getFilename()
if logNumber == 100: